@@ -1,4 +1,5 @@
 from pywapor.general.logger import log, adjust_logger
+from pywapor.general.processing_functions import adjust_timelim_dtype
 import types
 import functools
 import numpy as np
@@ -29,6 +30,9 @@ def collect_sources(folder, sources, latlim, lonlim, timelim, landsat_order_only
         dictionary with keys as (`source`, `product`) and values either filepaths or `xr.Dataset`s and an
         updated `sources` dictionary in which products that couldn't be downloaded have been removed. 
     """
+
+    adjust_logger(True, folder, "INFO")
+    timelim = adjust_timelim_dtype(timelim)
     
     reversed_sources, reversed_enhancers = reverse_sources(sources)
 
@@ -86,17 +90,23 @@ def collect_sources(folder, sources, latlim, lonlim, timelim, landsat_order_only
                 attempts[(source, product_name)] += max_attempts * 10
             except Exception as e:
 
-                exception_args = getattr(e, "args", tuple())
+                exception_args = getattr(e, "args", [""])
 
-                if "NetCDF: Filter error: unimplemented filter encountered" in str(exception_args[0]):
-                    info_url = r"https://github.com/Unidata/netcdf4-python/issues/1182"
-                    log.warning(f"--> Looks like you installed `netcdf4` incorrectly, see {info_url} for more info.")
+                give_warnings = True
 
-                if "Waiting for order of" in str(exception_args[0]):
-                    log.info(f"--> Continuing with collection of other sources while waiting for {exception_args[1]} `{source_name}.{product_name}` scenes to finish processing.")
-                    if landsat_order_only:
-                        attempts[(source, product_name)] += max_attempts * 10
-                elif attempts[(source, product_name)] < max_attempts - 1:
+                if len(exception_args) > 0:
+                    if "NetCDF: Filter error: unimplemented filter encountered" in str(exception_args[0]):
+                        info_url = r"https://github.com/Unidata/netcdf4-python/issues/1182"
+                        log.warning(f"--> Looks like you installed `netcdf4` incorrectly, see {info_url} for more info.")
+
+                if len(exception_args) > 0:
+                    if "Waiting for order of" in str(exception_args[0]):
+                        give_warnings = False
+                        log.info(f"--> Continuing with collection of other sources while waiting for {exception_args[1]} `{source_name}.{product_name}` scenes to finish processing.")
+                        if landsat_order_only:
+                            attempts[(source, product_name)] += max_attempts * 10
+
+                if attempts[(source, product_name)] < max_attempts - 1 and give_warnings:
                     log.warning(f"--> Collect attempt {attempts[(source, product_name)] + 1} of {max_attempts} for `{source_name}.{product_name}` failed, trying again after other sources have been collected. ({type(e).__name__}: {e}).")
                 else:
                     log.warning(f"--> Collect attempt {attempts[(source, product_name)] + 1} of {max_attempts} for `{source_name}.{product_name}` failed, giving up now, see full traceback below for more info. ({type(e).__name__}: {e}).")
